==> haskell-kan-extensions-5.0.1-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-8C1IYrFkmg9GBMq5Cy8sju
key: kan-extensions-5.0.1-8C1IYrFkmg9GBMq5Cy8sju
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
abi: b55f953f7ccb9511f8978a39cccc7b53
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-8C1IYrFkmg9GBMq5Cy8sju
depends:
    adjunctions-4.3-1gMD0Z5uC3t8kRhgQQXsie array-0.5.1.1 base-4.9.0.0
    comonad-5-Fqo2X68HwzQ5YCuLU8LFXN containers-0.5.7.1
    contravariant-1.4-KR4p8mcznnoInwULOlg5FR
    distributive-0.5.0.2-8lDT4wd8x255lSvuhyWdwG
    free-4.12.4-SEuDyLHdpfFkS6mcOQdg7 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    semigroupoids-5.0.1-JPPa1GAAznpIwjHipiGWj7
    tagged-0.8.4-9gtrXrOYlY5BIFTjUM7KTh transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.0.1-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-1UUyP5sa9MdEeCoHWqBIoU
key: kan-extensions-5.0.1-1UUyP5sa9MdEeCoHWqBIoU
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
abi: cbb74627b0bf0ff67e22eea838b0db7f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/kan-extensions-5.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-1UUyP5sa9MdEeCoHWqBIoU
depends:
    adjunctions-4.3-4qy0FfHNz7OiNMKhiFjXx array-0.5.1.1 base-4.9.0.0
    comonad-5-Fqo2X68HwzQ5YCuLU8LFXN containers-0.5.7.1
    contravariant-1.4-KR4p8mcznnoInwULOlg5FR
    distributive-0.5.0.2-8lDT4wd8x255lSvuhyWdwG
    free-4.12.4-9ks20BjLkfuIM98uYP5XGi mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    semigroupoids-5.1-5jnCvjsOzwJ9gIFAA8m8gv
    tagged-0.8.4-9gtrXrOYlY5BIFTjUM7KTh transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
